@@ -87,9 +87,13 @@ MAs = ['MA9', 'MA14', 'MA25', 'MA40', 'MA60', 'MA90', 'MA128', 'MA200']
 # SOPR
 SOPR = 'SOPR'
 
-# Signals
+# Oracle
 SIG = 'Sig'
 
+# API
+BAL = 'Bal'
+NAME = 'Name'
+
 # Misc
 POLY_CRYPTO_SYMBOLS = [
     'X%3ABTCUSD', 'X%3AETHUSD',
@@ -203,6 +207,13 @@ class PathFinder:
             'signals.csv'
         )
 
+    def get_orders_path(self):
+        return os.path.join(
+            MODELS_DIR,
+            'latest',
+            'orders.csv'
+        )
+
     def get_api_path(self, endpoint):
         return os.path.join(
             DATA_DIR,
