@@ -437,13 +437,18 @@ class MarketData:
 
 
 class IEXCloud(MarketData):
-    def __init__(self):
+    def __init__(self, test=False):
         super().__init__()
-        self.base = 'https://cloud.iexapis.com'
         self.version = 'v1'
-        self.token = os.environ['IEXCLOUD']
         self.provider = 'iexcloud'
 
+        if test:
+            self.base = 'https://sandbox.iexapis.com'
+            self.token = os.environ['IEXCLOUD_SANDBOX']
+        else:
+            self.base = 'https://cloud.iexapis.com'
+            self.token = os.environ['IEXCLOUD']
+
     def get_dividends(self, **kwargs):
         # given a symbol, return the dividend history
         def _get_dividends(symbol, timeframe='3m'):
@@ -607,6 +612,15 @@ class IEXCloud(MarketData):
                 if data == []:
                     continue
 
+                df = pd.DataFrame(data)
+                df['date'] = pd.to_datetime(df['date'] + ' ' + df['minute'])
+
+                # if all values are na except time, then skip
+                num_data_rows = len(
+                    df.drop(columns=['date', 'minute']).dropna(how='all'))
+                if (num_data_rows == 0):
+                    continue
+
                 res_cols = ['date', 'minute', 'marketOpen', 'marketHigh',
                             'marketLow', 'marketClose', 'marketVolume',
                             'marketAverage', 'marketNumberOfTrades']
@@ -614,9 +628,10 @@ class IEXCloud(MarketData):
                             'close', 'volume', 'average', 'trades']
 
                 columns = dict(zip(res_cols, std_cols))
-                df = pd.DataFrame(data)[res_cols].rename(columns=columns)
-                df['date'] = pd.to_datetime(df['date'] + ' ' + df['minute'])
+
+                df = df[res_cols].rename(columns=columns)
                 df.drop(columns='minute', inplace=True)
+
                 filename = self.finder.get_intraday_path(
                     symbol, date, self.provider)
                 df = self.standardize_ohlc(symbol, df, filename)
