@@ -49,6 +49,19 @@ class Historian:
         out = s.to_numpy().flatten()
         return out
 
+    def unfill(self, xs):
+        if not len(xs):
+            return xs
+        curr = xs[0]
+        new = [curr]
+        for x in xs[1:]:
+            if curr != x:
+                new.append(x)
+                curr = x
+            else:
+                new.append(None)
+        return new
+
     def get_optimal_signals(self, close, n=10, method='ffill'):
         # finds the optimal signals for an array of prices
         close = np.array(close)
